@@ -1,13 +1,17 @@
 
 import unittest
+import threading
 
-from mox import MoxTestBase, IsA
+from mox3.mox import MoxTestBase, IsA
+import gevent.monkey
 import spf
 
 from slimta.spf import EnforceSpf
 from slimta.envelope import Envelope
 from slimta.smtp.reply import Reply
 
+gevent.monkey.patch_all()
+
 
 class TestEnforceSpf(MoxTestBase):
 
@@ -17,8 +21,7 @@ class TestEnforceSpf(MoxTestBase):
 
     def test_bad_result_type(self):
         espf = EnforceSpf()
-        with self.assertRaises(ValueError):
-            espf.set_enforcement('asdf')
+        self.assertRaises(ValueError, espf.set_enforcement, 'asdf')
         espf.set_enforcement('PASS')
         espf.set_enforcement('pass')
 
